<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="cs_CZ">
<context>
    <name>AboutDialog</name>
    <message>
        <source>about_dialog_title</source>
        <translation type="obsolete">O programu</translation>
    </message>
    <message>
        <source>web_page</source>
        <translation type="obsolete">Domovské stránky</translation>
    </message>
    <message>
        <source>close</source>
        <translation type="obsolete">Zavřít</translation>
    </message>
    <message>
        <location filename="../src/main_window/ui/AboutDialog.ui" line="23"/>
        <source>About UGENE</source>
        <translation>O programu UGENE</translation>
    </message>
    <message>
        <location filename="../src/main_window/ui/AboutDialog.ui" line="60"/>
        <source>Web Page</source>
        <translation>Domovské stránky</translation>
    </message>
    <message>
        <location filename="../src/main_window/ui/AboutDialog.ui" line="80"/>
        <source>Close</source>
        <translation>Zavřít</translation>
    </message>
</context>
<context>
    <name>AppContextImpl</name>
    <message>
        <location filename="../src/Main.cpp" line="253"/>
        <source>UGENE initialization started</source>
        <translation type="unfinished">Začalo spouštění UGENE</translation>
    </message>
    <message>
        <location filename="../src/Main.cpp" line="273"/>
        <source>Style not available %1</source>
        <translation type="unfinished">Styl není dostupný %1</translation>
    </message>
    <message>
        <location filename="../src/Main.cpp" line="440"/>
        <source>UGENE started</source>
        <translation type="unfinished">UGENE bylo spuštěno</translation>
    </message>
</context>
<context>
    <name>AppSettingsDialog</name>
    <message>
        <location filename="../src/app_settings/ui/AppSettingsDialog.ui" line="13"/>
        <source>AppSettingsDialog</source>
        <translation>Nastavení aplikace</translation>
    </message>
    <message>
        <location filename="../src/app_settings/ui/AppSettingsDialog.ui" line="49"/>
        <source>1</source>
        <translation>1</translation>
    </message>
    <message>
        <location filename="../src/app_settings/ui/AppSettingsDialog.ui" line="81"/>
        <source>ok</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../src/app_settings/ui/AppSettingsDialog.ui" line="88"/>
        <source>cancel</source>
        <translation>Zrušit</translation>
    </message>
</context>
<context>
    <name>CreateNewProjectDialog</name>
    <message>
        <location filename="../src/project_support/ui/CreateNewProjectWidget.ui" line="20"/>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <location filename="../src/project_support/ui/CreateNewProjectWidget.ui" line="47"/>
        <source>project_name_label</source>
        <translation>Název projektu:</translation>
    </message>
    <message>
        <location filename="../src/project_support/ui/CreateNewProjectWidget.ui" line="57"/>
        <source>project_folder_label</source>
        <translation>Složka s projektem:</translation>
    </message>
    <message>
        <location filename="../src/project_support/ui/CreateNewProjectWidget.ui" line="64"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../src/project_support/ui/CreateNewProjectWidget.ui" line="71"/>
        <source>project_file_label</source>
        <translation>Soubor s projektem</translation>
    </message>
    <message>
        <location filename="../src/project_support/ui/CreateNewProjectWidget.ui" line="104"/>
        <source>create_button_label</source>
        <translation>Vytvořit</translation>
    </message>
    <message>
        <location filename="../src/project_support/ui/CreateNewProjectWidget.ui" line="114"/>
        <source>cancel_button_label</source>
        <translation>Zrušit</translation>
    </message>
</context>
<context>
    <name>ExportProjectDialog</name>
    <message>
        <location filename="../src/project_support/ui/ExportProjectDialog.ui" line="14"/>
        <source>Export Project</source>
        <translation>Vyvést projekt</translation>
    </message>
    <message>
        <location filename="../src/project_support/ui/ExportProjectDialog.ui" line="25"/>
        <source>Destination folder</source>
        <translation>Cílová složka</translation>
    </message>
    <message>
        <location filename="../src/project_support/ui/ExportProjectDialog.ui" line="42"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../src/project_support/ui/ExportProjectDialog.ui" line="49"/>
        <source>Project file name</source>
        <translation>Název souboru s projektem</translation>
    </message>
    <message>
        <location filename="../src/project_support/ui/ExportProjectDialog.ui" line="96"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../src/project_support/ui/ExportProjectDialog.ui" line="103"/>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
</context>
<context>
    <name>LogSettingsWidget</name>
    <message>
        <location filename="../src/app_settings/logview_settings/ui/LogSettingsWidget.ui" line="14"/>
        <source>LogSettingsWidget</source>
        <translation>Nastavení zápisu</translation>
    </message>
    <message>
        <location filename="../src/app_settings/logview_settings/ui/LogSettingsWidget.ui" line="47"/>
        <source>Log format</source>
        <translation>Formát zápisu</translation>
    </message>
    <message>
        <location filename="../src/app_settings/logview_settings/ui/LogSettingsWidget.ui" line="53"/>
        <source>Show date</source>
        <translation>Ukázat datum</translation>
    </message>
    <message>
        <location filename="../src/app_settings/logview_settings/ui/LogSettingsWidget.ui" line="60"/>
        <source>Show log level</source>
        <translation>Ukázat úroveň zápisu</translation>
    </message>
    <message>
        <location filename="../src/app_settings/logview_settings/ui/LogSettingsWidget.ui" line="67"/>
        <source>Show log category</source>
        <translation>Ukázat skupinu zápisu</translation>
    </message>
    <message>
        <source>category_name</source>
        <translation type="obsolete">Skupina</translation>
    </message>
    <message>
        <source>trace_level</source>
        <translation type="obsolete">Stopa</translation>
    </message>
    <message>
        <source>details_level</source>
        <translation type="obsolete">Podrobnosti</translation>
    </message>
    <message>
        <source>info_level</source>
        <translation type="obsolete">Informace</translation>
    </message>
    <message>
        <source>error_level</source>
        <translation type="obsolete">Chyby</translation>
    </message>
    <message>
        <source>message_format_group</source>
        <translation type="obsolete">Formát zápisu</translation>
    </message>
    <message>
        <source>show_date</source>
        <translation type="obsolete">Ukázat datum</translation>
    </message>
    <message>
        <source>show_level</source>
        <translation type="obsolete">Ukázat úroveň zápisu</translation>
    </message>
    <message>
        <source>show_category</source>
        <translation type="obsolete">Ukázat skupinu zápisu</translation>
    </message>
</context>
<context>
    <name>NetworkSettingsWidget</name>
    <message>
        <location filename="../src/app_settings/network_settings/ui/NetworkSettingsWidget.ui" line="20"/>
        <source>network_settings_title</source>
        <translation>Nastavení sítě</translation>
    </message>
    <message>
        <location filename="../src/app_settings/network_settings/ui/NetworkSettingsWidget.ui" line="32"/>
        <source>proxy_group_label</source>
        <translation>Proxy</translation>
    </message>
    <message>
        <location filename="../src/app_settings/network_settings/ui/NetworkSettingsWidget.ui" line="40"/>
        <source>type_label</source>
        <translation>Typ:</translation>
    </message>
    <message>
        <location filename="../src/app_settings/network_settings/ui/NetworkSettingsWidget.ui" line="47"/>
        <source>server_label</source>
        <translation>Server:</translation>
    </message>
    <message>
        <location filename="../src/app_settings/network_settings/ui/NetworkSettingsWidget.ui" line="54"/>
        <source>port_l</source>
        <translation>Přípojka:</translation>
    </message>
    <message>
        <location filename="../src/app_settings/network_settings/ui/NetworkSettingsWidget.ui" line="67"/>
        <source>http_l</source>
        <translation>HTTP</translation>
    </message>
    <message>
        <location filename="../src/app_settings/network_settings/ui/NetworkSettingsWidget.ui" line="105"/>
        <source>Use authentication with HTTP proxy:</source>
        <translation>Použít prokázání pravosti pomocí HTTP proxy:</translation>
    </message>
    <message>
        <location filename="../src/app_settings/network_settings/ui/NetworkSettingsWidget.ui" line="117"/>
        <source>Login</source>
        <translation>Přihlášení (login)</translation>
    </message>
    <message>
        <location filename="../src/app_settings/network_settings/ui/NetworkSettingsWidget.ui" line="127"/>
        <source>Password</source>
        <translation>Heslo</translation>
    </message>
    <message>
        <location filename="../src/app_settings/network_settings/ui/NetworkSettingsWidget.ui" line="189"/>
        <source>exceptions_check_label</source>
        <translation>Nepoužívejte proxy na následující adresy (pro každou oddělený řádek):</translation>
    </message>
    <message>
        <location filename="../src/app_settings/network_settings/ui/NetworkSettingsWidget.ui" line="205"/>
        <source>SSL settings</source>
        <translation>Nastavení SSL</translation>
    </message>
    <message>
        <location filename="../src/app_settings/network_settings/ui/NetworkSettingsWidget.ui" line="213"/>
        <source>Secure Socket protocol:</source>
        <translation>Protokol bezpečná zásuvka (Secure Socket):</translation>
    </message>
</context>
<context>
    <name>PluginViewWidget</name>
    <message>
        <location filename="../src/plugin_viewer/ui/PluginViewerWidget.ui" line="13"/>
        <source>Plugin Viewer</source>
        <translation>Prohlížeč přídavných modulů</translation>
    </message>
    <message>
        <location filename="../src/plugin_viewer/ui/PluginViewerWidget.ui" line="41"/>
        <source>item_type_label</source>
        <translation>Typ</translation>
    </message>
    <message>
        <location filename="../src/plugin_viewer/ui/PluginViewerWidget.ui" line="46"/>
        <source>item_name_label</source>
        <translation>Název</translation>
    </message>
    <message>
        <location filename="../src/plugin_viewer/ui/PluginViewerWidget.ui" line="51"/>
        <source>item_state_label</source>
        <translation>Stav</translation>
    </message>
    <message>
        <location filename="../src/plugin_viewer/ui/PluginViewerWidget.ui" line="56"/>
        <source>item_desc_label</source>
        <translation>Popis</translation>
    </message>
</context>
<context>
    <name>ProjectViewWidget</name>
    <message>
        <location filename="../src/project_view/ui/ProjectViewWidget.ui" line="13"/>
        <source>Form</source>
        <translation>Formulář</translation>
    </message>
    <message>
        <location filename="../src/project_view/ui/ProjectViewWidget.ui" line="55"/>
        <source>Name filter</source>
        <translation>Filtr názvů</translation>
    </message>
    <message>
        <location filename="../src/project_view/ui/ProjectViewWidget.ui" line="118"/>
        <source>Bookmarks</source>
        <translation>Záložky</translation>
    </message>
    <message>
        <location filename="../src/project_view/ui/ProjectViewWidget.ui" line="83"/>
        <source>Objects</source>
        <translation>Předměty</translation>
    </message>
</context>
<context>
    <name>ResourceSettingsWidget</name>
    <message>
        <location filename="../src/app_settings/resource_settings/ui/ResourceSettingsWidget.ui" line="13"/>
        <source>Resource settings</source>
        <translation>Nastavení zdrojů</translation>
    </message>
    <message>
        <location filename="../src/app_settings/resource_settings/ui/ResourceSettingsWidget.ui" line="19"/>
        <source>Application resources</source>
        <translation>Zdroje aplikace</translation>
    </message>
    <message>
        <location filename="../src/app_settings/resource_settings/ui/ResourceSettingsWidget.ui" line="31"/>
        <source>Optimize for CPU count</source>
        <translation>Vyladit pro počítání CPU</translation>
    </message>
    <message>
        <location filename="../src/app_settings/resource_settings/ui/ResourceSettingsWidget.ui" line="63"/>
        <source>Tasks memory limit</source>
        <translation>Omezení paměti pro úkoly</translation>
    </message>
    <message>
        <location filename="../src/app_settings/resource_settings/ui/ResourceSettingsWidget.ui" line="82"/>
        <source>Mb</source>
        <translation>MB</translation>
    </message>
    <message>
        <location filename="../src/app_settings/resource_settings/ui/ResourceSettingsWidget.ui" line="104"/>
        <source>Threads limit</source>
        <translation>Omezení vláken</translation>
    </message>
</context>
<context>
    <name>ScriptLibraryEditor</name>
    <message>
        <location filename="../src/script/ui/ScriptLibraryEditor.ui" line="14"/>
        <source>Form</source>
        <translation>Formulář</translation>
    </message>
    <message>
        <location filename="../src/script/ui/ScriptLibraryEditor.ui" line="20"/>
        <source>Folders to search scripts</source>
        <translation>Složky, v nichž se mají hledat skripty</translation>
    </message>
    <message>
        <location filename="../src/script/ui/ScriptLibraryEditor.ui" line="30"/>
        <source>Add folder</source>
        <translation>Přidat složku</translation>
    </message>
    <message>
        <location filename="../src/script/ui/ScriptLibraryEditor.ui" line="37"/>
        <source>Remove folder</source>
        <translation>Odstranit složku</translation>
    </message>
    <message>
        <location filename="../src/script/ui/ScriptLibraryEditor.ui" line="57"/>
        <source>Available scripts</source>
        <translation>Dostupné skripty</translation>
    </message>
    <message>
        <location filename="../src/script/ui/ScriptLibraryEditor.ui" line="67"/>
        <source>Refresh</source>
        <translation>Obnovit</translation>
    </message>
    <message>
        <location filename="../src/script/ui/ScriptLibraryEditor.ui" line="74"/>
        <source>Edit</source>
        <translation>Upravit</translation>
    </message>
    <message>
        <location filename="../src/script/ui/ScriptLibraryEditor.ui" line="94"/>
        <source>Script preview</source>
        <translation>Náhled na skript</translation>
    </message>
    <message>
        <location filename="../src/script/ui/ScriptLibraryEditor.ui" line="108"/>
        <source>Close</source>
        <translation>Zavřít</translation>
    </message>
</context>
<context>
    <name>ScriptManagerWidget</name>
    <message>
        <source>script_manager</source>
        <translation type="obsolete">Soupis skriptů</translation>
    </message>
    <message>
        <source>add_b</source>
        <translation type="obsolete">Přidat skript</translation>
    </message>
    <message>
        <source>reload_b</source>
        <translation type="obsolete">Nahrát skript znovu</translation>
    </message>
    <message>
        <source>del_b</source>
        <translation type="obsolete">Odstranit skript</translation>
    </message>
    <message>
        <source>script_name</source>
        <translation type="obsolete">Název</translation>
    </message>
    <message>
        <source>script_type</source>
        <translation type="obsolete">Typ</translation>
    </message>
    <message>
        <source>script_url</source>
        <translation type="obsolete">Soubor</translation>
    </message>
    <message>
        <source>script_status</source>
        <translation type="obsolete">Stav</translation>
    </message>
    <message>
        <source>close_b</source>
        <translation type="obsolete">Zavřít</translation>
    </message>
</context>
<context>
    <name>U2::AboutDialogController</name>
    <message>
        <location filename="../src/main_window/AboutDialogController.cpp" line="51"/>
        <source>Max score: %1</source>
        <translation>Největší výsledek: %1</translation>
    </message>
    <message>
        <location filename="../src/main_window/AboutDialogController.cpp" line="95"/>
        <source>Score: %1</source>
        <translation>Výsledek: %1</translation>
    </message>
    <message>
        <location filename="../src/main_window/AboutDialogController.cpp" line="99"/>
        <source>Level: %1</source>
        <translation>Úroveň: %1</translation>
    </message>
    <message>
        <location filename="../src/main_window/AboutDialogController.cpp" line="105"/>
        <source>About UGENE</source>
        <translation>O programu UGENE</translation>
    </message>
    <message>
        <location filename="../src/main_window/AboutDialogController.cpp" line="107"/>
        <source>Have fun ;-)</source>
        <translation>Mějte se krásně °_^</translation>
    </message>
</context>
<context>
    <name>U2::AppContextImpl</name>
    <message>
        <source>UGENE initialization started</source>
        <translation type="obsolete">Začalo spouštění UGENE</translation>
    </message>
    <message>
        <source>Style not available %1</source>
        <translation type="obsolete">Styl není dostupný %1</translation>
    </message>
    <message>
        <source>UGENE started</source>
        <translation type="obsolete">UGENE bylo spuštěno</translation>
    </message>
</context>
<context>
    <name>U2::AppSettingsDialogController</name>
    <message>
        <location filename="../src/app_settings/AppSettingsDialogController.cpp" line="49"/>
        <source>default_err</source>
        <translation>Chyba</translation>
    </message>
    <message>
        <location filename="../src/app_settings/AppSettingsDialogController.cpp" line="51"/>
        <source>error</source>
        <translation>Chyba</translation>
    </message>
</context>
<context>
    <name>U2::AppSettingsGUIImpl</name>
    <message>
        <location filename="../src/app_settings/AppSettingsGUIImpl.cpp" line="19"/>
        <source>Preferences...</source>
        <translation>Nastavení...</translation>
    </message>
</context>
<context>
    <name>U2::CheckUpdatesTask</name>
    <message>
        <location filename="../src/main_window/CheckUpdatesTask.cpp" line="17"/>
        <source>Check for updates</source>
        <translation>Prověřit aktualizace</translation>
    </message>
    <message>
        <location filename="../src/main_window/CheckUpdatesTask.cpp" line="26"/>
        <source>Connecting to updates server</source>
        <translation>Připojuje se k aktualizačnímu serveru</translation>
    </message>
    <message>
        <location filename="../src/main_window/CheckUpdatesTask.cpp" line="38"/>
        <source>Connection error: %1</source>
        <translation>Chyba spojení: %1</translation>
    </message>
    <message>
        <location filename="../src/main_window/CheckUpdatesTask.cpp" line="49"/>
        <source>Your version:</source>
        <translation>Vaše verze:</translation>
    </message>
    <message>
        <location filename="../src/main_window/CheckUpdatesTask.cpp" line="50"/>
        <source>Latest version:</source>
        <translation>Poslední verze:</translation>
    </message>
    <message>
        <location filename="../src/main_window/CheckUpdatesTask.cpp" line="53"/>
        <source>You have the latest  version</source>
        <translation>Máte poslední verzi</translation>
    </message>
    <message>
        <location filename="../src/main_window/CheckUpdatesTask.cpp" line="57"/>
        <source>Version information</source>
        <translation>Údaj o verzi</translation>
    </message>
    <message>
        <location filename="../src/main_window/CheckUpdatesTask.cpp" line="62"/>
        <source>Visit web site</source>
        <translation>Navštivte internetové stránky</translation>
    </message>
</context>
<context>
    <name>U2::CloseProjectTask</name>
    <message>
        <location filename="../src/project_support/ProjectTasksGui.cpp" line="46"/>
        <source>close_project_task_name</source>
        <translation>Zavřít projekt</translation>
    </message>
    <message>
        <location filename="../src/project_support/ProjectTasksGui.cpp" line="52"/>
        <source>error_no_active_project</source>
        <translation>Nenalezen žádný činný projekt</translation>
    </message>
    <message>
        <location filename="../src/project_support/ProjectTasksGui.cpp" line="70"/>
        <source>Save and close project</source>
        <translation>Uložit a zavřít projekt</translation>
    </message>
</context>
<context>
    <name>U2::DisablePluginViewerTask</name>
    <message>
        <location filename="../src/plugin_viewer/PluginViewerImpl.cpp" line="35"/>
        <source>disable_plugin_viewer_task</source>
        <translation>Vypnout prohlížeč přídavných modulů</translation>
    </message>
</context>
<context>
    <name>U2::DisableProjectViewTask</name>
    <message>
        <location filename="../src/project_view/ProjectViewImpl.cpp" line="814"/>
        <source>disable_project_view</source>
        <translation>Vypnout prohlížení projektů</translation>
    </message>
</context>
<context>
    <name>U2::EnablePluginViewerTask</name>
    <message>
        <location filename="../src/plugin_viewer/PluginViewerImpl.cpp" line="23"/>
        <source>enable_plugin_viewer_task</source>
        <translation>Zapnout prohlížeč přídavných modulů</translation>
    </message>
</context>
<context>
    <name>U2::EnableProjectViewTask</name>
    <message>
        <location filename="../src/project_view/ProjectViewImpl.cpp" line="802"/>
        <source>enable_project_view</source>
        <translation>Zapnout prohlížení projektů</translation>
    </message>
</context>
<context>
    <name>U2::ExportProjectDialogController</name>
    <message>
        <location filename="../src/project_support/ExportProjectDialogController.cpp" line="48"/>
        <source>Choose Directory</source>
        <translation>Vybrat adresář</translation>
    </message>
</context>
<context>
    <name>U2::ExportProjectTask</name>
    <message>
        <location filename="../src/project_support/ProjectTasksGui.cpp" line="420"/>
        <source>Export project task</source>
        <translation>Vyvést projektový úkol</translation>
    </message>
    <message>
        <location filename="../src/project_support/ProjectTasksGui.cpp" line="432"/>
        <source>One of the documents has empty URL</source>
        <translation>Jeden z dokumentů má prázdnou adresu (URL)</translation>
    </message>
    <message>
        <source>Error during coping documents</source>
        <translation type="obsolete">Chyba při kopírování dokumentů</translation>
    </message>
</context>
<context>
    <name>U2::GTest_ExportProject</name>
    <message>
        <location filename="../src/project_support/ProjectTasksGui.cpp" line="555"/>
        <source>GTest_ExportProject::prepare unable to clean directory for exporting</source>
        <translation>GTest_ExportProject::prepare nelze uklidit adresář pro vyvedení</translation>
    </message>
    <message>
        <location filename="../src/project_support/ProjectTasksGui.cpp" line="560"/>
        <source>GTest_ExportProject::prepare unable to create directory for exporting</source>
        <translation>GTest_ExportProject::prepare nelze vytvořit adresář pro vyvedení</translation>
    </message>
    <message>
        <location filename="../src/project_support/ProjectTasksGui.cpp" line="580"/>
        <source>GTest_ExportProject::cleanup unable to delete exported files</source>
        <translation>GTest_ExportProject::cleanup nelze smazat vyvedené soubory</translation>
    </message>
</context>
<context>
    <name>U2::GTest_LoadDocumentFromProject</name>
    <message>
        <location filename="../src/project_support/ProjectTasksGui.cpp" line="641"/>
        <source>No project loaded</source>
        <translation>Nenahrán žádný projekt</translation>
    </message>
    <message>
        <location filename="../src/project_support/ProjectTasksGui.cpp" line="645"/>
        <source>Document name to load is empty</source>
        <translation>Název dokumentu k nahrání je prázdný</translation>
    </message>
    <message>
        <location filename="../src/project_support/ProjectTasksGui.cpp" line="660"/>
        <source>File %1 not found in project</source>
        <translation>Soubor %1 v projektu nenalezen</translation>
    </message>
</context>
<context>
    <name>U2::GTest_LoadProject</name>
    <message>
        <location filename="../src/project_support/ProjectTasksGui.cpp" line="502"/>
        <source>Unload previous project, then load new</source>
        <translation>Vyložit předchozí projekt, potom nahrát nový</translation>
    </message>
</context>
<context>
    <name>U2::LoadProjectTask</name>
    <message>
        <location filename="../src/project_support/ProjectTasksGui.cpp" line="361"/>
        <source>load_project_task_name</source>
        <translation>Nahrát projekt</translation>
    </message>
    <message>
        <source>error_open_file %1</source>
        <translation type="obsolete">Chyba při otevírání souboru: %1</translation>
    </message>
    <message>
        <source>error_invalid_content %1</source>
        <translation type="obsolete">Soubor není souborem projektu: %1</translation>
    </message>
    <message>
        <source>last_loaded_state_was_locked_by_format</source>
        <translation type="obsolete">Byl zamknut během posledního nahrání</translation>
    </message>
    <message>
        <location filename="../src/project_support/ProjectTasksGui.cpp" line="372"/>
        <source>Loading project from: %1</source>
        <translation>Nahrává se projekt z: %1</translation>
    </message>
    <message>
        <location filename="../src/project_support/ProjectTasksGui.cpp" line="381"/>
        <source>Unable to detect parser for project</source>
        <translation>Nepodařilo se zjistit syntaktický analyzátor pro projekt</translation>
    </message>
    <message>
        <location filename="../src/project_support/ProjectTasksGui.cpp" line="386"/>
        <source>Project loaded: %1</source>
        <translation>Projekt nahrán: %1</translation>
    </message>
</context>
<context>
    <name>U2::LogSettingsPageController</name>
    <message>
        <source>log_settings</source>
        <translation type="obsolete">Nastavení zápisu</translation>
    </message>
    <message>
        <location filename="../src/app_settings/logview_settings/LogSettingsGUIController.cpp" line="17"/>
        <source>Logging</source>
        <translation>Nastavení zápisu</translation>
    </message>
</context>
<context>
    <name>U2::LogSettingsPageWidget</name>
    <message>
        <location filename="../src/app_settings/logview_settings/LogSettingsGUIController.cpp" line="57"/>
        <source>Category</source>
        <translation>Skupina</translation>
    </message>
    <message>
        <location filename="../src/app_settings/logview_settings/LogSettingsGUIController.cpp" line="64"/>
        <source>&lt;&lt;all&gt;&gt;</source>
        <translation>&lt;&lt;vše&gt;&gt;</translation>
    </message>
    <message>
        <location filename="../src/app_settings/logview_settings/LogSettingsGUIController.cpp" line="217"/>
        <source>Sample text</source>
        <translation>Ukázkový text</translation>
    </message>
</context>
<context>
    <name>U2::LogViewDockWidget</name>
    <message>
        <source>Log</source>
        <translation type="obsolete">Zápis</translation>
    </message>
    <message>
        <source>log_settings</source>
        <translation type="obsolete">&amp;Nastavení zápisu</translation>
    </message>
    <message>
        <source>logview_copy</source>
        <translation type="obsolete">Kopírovat do schránky</translation>
    </message>
    <message>
        <source>logview_set_case</source>
        <translation type="obsolete">Rozlišovat psaní velkých a malých písmen</translation>
    </message>
    <message>
        <source>logview_use_regexp</source>
        <translation type="obsolete">Použít regulární výrazy</translation>
    </message>
    <message>
        <source>TRACE</source>
        <translation type="obsolete">STOPA</translation>
    </message>
    <message>
        <source>DETAILS</source>
        <translation type="obsolete">PODROBNOSTI</translation>
    </message>
    <message>
        <source>INFO</source>
        <translation type="obsolete">INFORMACE</translation>
    </message>
    <message>
        <source>ERROR</source>
        <translation type="obsolete">CHYBA</translation>
    </message>
    <message>
        <source>Dump performance counters</source>
        <translation type="obsolete">Vyhodit počítadla výkonu</translation>
    </message>
    <message>
        <source>Append separator</source>
        <translation type="obsolete">Připojit oddělovač</translation>
    </message>
    <message>
        <source>Clear log</source>
        <translation type="obsolete">Vyprázdnit zápis</translation>
    </message>
</context>
<context>
    <name>U2::MWMDIManagerImpl</name>
    <message>
        <location filename="../src/main_window/MDIManagerImpl.cpp" line="41"/>
        <source>close_active_view</source>
        <translation>Zavřít činný pohled</translation>
    </message>
    <message>
        <location filename="../src/main_window/MDIManagerImpl.cpp" line="43"/>
        <source>close_active_view_statustip</source>
        <translation>Zavřít činný pohled</translation>
    </message>
    <message>
        <location filename="../src/main_window/MDIManagerImpl.cpp" line="46"/>
        <source>close_all_mdi_windows</source>
        <translation>Zavřít všechna okna</translation>
    </message>
    <message>
        <location filename="../src/main_window/MDIManagerImpl.cpp" line="47"/>
        <source>close_all_mdi_windows_statustip</source>
        <translation>Zavřít všechna okna</translation>
    </message>
    <message>
        <location filename="../src/main_window/MDIManagerImpl.cpp" line="50"/>
        <source>tile_mdi_windows</source>
        <translation>Klást okna vedle sebe</translation>
    </message>
    <message>
        <location filename="../src/main_window/MDIManagerImpl.cpp" line="51"/>
        <source>tile_mdi_windows_statustip</source>
        <translation>Klást okna vedle sebe</translation>
    </message>
    <message>
        <location filename="../src/main_window/MDIManagerImpl.cpp" line="54"/>
        <source>cascade_mdi_windows</source>
        <translation>Překrývat okna</translation>
    </message>
    <message>
        <location filename="../src/main_window/MDIManagerImpl.cpp" line="55"/>
        <source>cascade_mdi_windows_statustip</source>
        <translation>Překrývat okna</translation>
    </message>
    <message>
        <location filename="../src/main_window/MDIManagerImpl.cpp" line="58"/>
        <source>next_mdi_window</source>
        <translation>Další okno</translation>
    </message>
    <message>
        <location filename="../src/main_window/MDIManagerImpl.cpp" line="59"/>
        <source>next_mdi_window_statustip</source>
        <translation>Další okno</translation>
    </message>
    <message>
        <location filename="../src/main_window/MDIManagerImpl.cpp" line="63"/>
        <source>previous_mdi_window</source>
        <translation>Předchozí okno</translation>
    </message>
    <message>
        <location filename="../src/main_window/MDIManagerImpl.cpp" line="64"/>
        <source>previous_mdi_window_statustip</source>
        <translation>Předchozí okno</translation>
    </message>
    <message>
        <source>Closing window %1</source>
        <translation type="obsolete">Zavírá se okno %1</translation>
    </message>
    <message>
        <source>Adding window: %1</source>
        <translation type="obsolete">Přidává se okno %1</translation>
    </message>
</context>
<context>
    <name>U2::MWMenuManagerImpl</name>
    <message>
        <location filename="../src/main_window/MenuManager.cpp" line="10"/>
        <source>mw_menu_file</source>
        <translation>&amp;Soubor</translation>
    </message>
    <message>
        <location filename="../src/main_window/MenuManager.cpp" line="11"/>
        <source>mw_menu_actions</source>
        <translation>&amp;Činnosti</translation>
    </message>
    <message>
        <location filename="../src/main_window/MenuManager.cpp" line="12"/>
        <source>mw_menu_settings</source>
        <translation>&amp;Nastavení</translation>
    </message>
    <message>
        <location filename="../src/main_window/MenuManager.cpp" line="13"/>
        <source>mw_menu_tools</source>
        <translation>&amp;Nástroje</translation>
    </message>
    <message>
        <location filename="../src/main_window/MenuManager.cpp" line="14"/>
        <source>mw_menu_window</source>
        <translation>&amp;Okno</translation>
    </message>
    <message>
        <location filename="../src/main_window/MenuManager.cpp" line="15"/>
        <source>mw_menu_help</source>
        <translation>&amp;Nápověda</translation>
    </message>
</context>
<context>
    <name>U2::MainWindowImpl</name>
    <message>
        <location filename="../src/main_window/MainWindowImpl.cpp" line="155"/>
        <source>mw_menu_file_exit</source>
        <translation>U&amp;končit</translation>
    </message>
    <message>
        <location filename="../src/main_window/MainWindowImpl.cpp" line="170"/>
        <source>Download user manual</source>
        <translation>Stáhnout uživatelskou příručku</translation>
    </message>
    <message>
        <location filename="../src/main_window/MainWindowImpl.cpp" line="193"/>
        <location filename="../src/main_window/MainWindowImpl.cpp" line="195"/>
        <source>main_window_title</source>
        <translation>UGENE</translation>
    </message>
    <message>
        <location filename="../src/main_window/MainWindowImpl.cpp" line="236"/>
        <source>UGENE</source>
        <translation>UGENE</translation>
    </message>
    <message>
        <location filename="../src/main_window/MainWindowImpl.cpp" line="237"/>
        <source>Shutdown already in process. Close UGENE immediately</source>
        <translation>Vypínání již probíhá. Zavřít UGENE okamžitě</translation>
    </message>
    <message>
        <location filename="../src/main_window/MainWindowImpl.cpp" line="238"/>
        <source>Close</source>
        <translation>Zavřít</translation>
    </message>
    <message>
        <location filename="../src/main_window/MainWindowImpl.cpp" line="239"/>
        <source>Wait</source>
        <translation>Počkat</translation>
    </message>
    <message>
        <location filename="../src/main_window/MainWindowImpl.cpp" line="159"/>
        <source>mw_menu_help_about</source>
        <translation>&amp;O programu</translation>
    </message>
    <message>
        <location filename="../src/main_window/MainWindowImpl.cpp" line="167"/>
        <source>Check for Updates</source>
        <translation>Prověřit na novější vydání</translation>
    </message>
    <message>
        <location filename="../src/main_window/MainWindowImpl.cpp" line="164"/>
        <source>Visit UGENE&apos;s Web Site</source>
        <translation>Navštivte internetové stránky UGENE</translation>
    </message>
</context>
<context>
    <name>U2::NetworkSettingsPageController</name>
    <message>
        <source>network_settings</source>
        <translation type="obsolete">Nastavení sítě</translation>
    </message>
    <message>
        <location filename="../src/app_settings/network_settings/NetworkSettingsGUIController.cpp" line="15"/>
        <source>Network</source>
        <translation>Sítě</translation>
    </message>
</context>
<context>
    <name>U2::OpenProjectTask</name>
    <message>
        <location filename="../src/project_support/ProjectTasksGui.cpp" line="77"/>
        <location filename="../src/project_support/ProjectTasksGui.cpp" line="82"/>
        <source>open_project_task_name</source>
        <translation>Otevřít projekt/dokument</translation>
    </message>
    <message>
        <location filename="../src/project_support/ProjectTasksGui.cpp" line="98"/>
        <source>invalid_url%1</source>
        <translation>Nečitelný soubor: %1</translation>
    </message>
    <message>
        <location filename="../src/project_support/ProjectTasksGui.cpp" line="105"/>
        <location filename="../src/project_support/ProjectTasksGui.cpp" line="106"/>
        <source>Project already opened</source>
        <translation>Projekt již otevřen</translation>
    </message>
    <message>
        <location filename="../src/project_support/ProjectTasksGui.cpp" line="111"/>
        <source>UGENE</source>
        <translation>UGENE</translation>
    </message>
    <message>
        <location filename="../src/project_support/ProjectTasksGui.cpp" line="112"/>
        <source>New project can either be opened in a new window or replace the project in the existing. How would you like to open the project?</source>
        <translation>Nový projekt může být buď otevřen v novém okně nebo nahradit projekt ve stávajícím. Jak chcete, aby byl projekt otevřen?</translation>
    </message>
    <message>
        <location filename="../src/project_support/ProjectTasksGui.cpp" line="113"/>
        <source>New Window</source>
        <translation>Nové okno</translation>
    </message>
    <message>
        <location filename="../src/project_support/ProjectTasksGui.cpp" line="114"/>
        <source>This Window</source>
        <translation>Toto okno</translation>
    </message>
    <message>
        <location filename="../src/project_support/ProjectTasksGui.cpp" line="122"/>
        <source>Failed to open new instance of UGENE</source>
        <translation>Nepodařilo se otevřít nový běh UGENE</translation>
    </message>
    <message>
        <location filename="../src/project_support/ProjectTasksGui.cpp" line="169"/>
        <source>unsupported_document%1</source>
        <translation>Neznámý formát dokumentu: %1</translation>
    </message>
    <message>
        <location filename="../src/project_support/ProjectTasksGui.cpp" line="184"/>
        <source>Document wasn&apos;t added to project: unsupported format</source>
        <translation>Dokument nebyl do projektu přidán: nepodporovaný formát</translation>
    </message>
    <message>
        <location filename="../src/project_support/ProjectTasksGui.cpp" line="189"/>
        <source>warning</source>
        <translation>Varování</translation>
    </message>
    <message>
        <location filename="../src/project_support/ProjectTasksGui.cpp" line="189"/>
        <source>The document already in the project</source>
        <translation>Dokument je již v projektu</translation>
    </message>
    <message>
        <location filename="../src/project_support/ProjectTasksGui.cpp" line="198"/>
        <source>The document is already opened: %1</source>
        <translation>Dokument je již otevřen: %1</translation>
    </message>
    <message>
        <location filename="../src/project_support/ProjectTasksGui.cpp" line="162"/>
        <source>ignore %1</source>
        <translation>Nevšímat si %1</translation>
    </message>
    <message>
        <location filename="../src/project_support/ProjectTasksGui.cpp" line="152"/>
        <source>Creating new project</source>
        <translation>Vytváří se nový projekt</translation>
    </message>
    <message>
        <source>Document is already opened: %1</source>
        <translation type="obsolete">Dokument je již otevřen: %1</translation>
    </message>
    <message>
        <location filename="../src/project_support/ProjectTasksGui.cpp" line="128"/>
        <source>Stopped loading project: %1. Reason: active project found</source>
        <translation>Nahrávání projektu bylo zastaveno: %1. Důvod: nalezen činný projekt</translation>
    </message>
</context>
<context>
    <name>U2::PluginViewerController</name>
    <message>
        <location filename="../src/plugin_viewer/PluginViewerController.cpp" line="47"/>
        <source>plugin_view_window_title</source>
        <translation>Prohlížeč přídavných modulů</translation>
    </message>
    <message>
        <location filename="../src/plugin_viewer/PluginViewerController.cpp" line="78"/>
        <source>Plugins...</source>
        <translation>Přídavné moduly...</translation>
    </message>
    <message>
        <location filename="../src/plugin_viewer/PluginViewerController.cpp" line="83"/>
        <source>add_plugin_label</source>
        <translation>Přidat přídavný modul</translation>
    </message>
    <message>
        <location filename="../src/plugin_viewer/PluginViewerController.cpp" line="92"/>
        <source>enable_service_label</source>
        <translation>Povolit službu</translation>
    </message>
    <message>
        <location filename="../src/plugin_viewer/PluginViewerController.cpp" line="95"/>
        <source>disable_service_label</source>
        <translation>Zakázat službu</translation>
    </message>
    <message>
        <location filename="../src/plugin_viewer/PluginViewerController.cpp" line="239"/>
        <source>add_plugin_caption</source>
        <translation>Vybrat soubor s přídavným modulem</translation>
    </message>
    <message>
        <location filename="../src/plugin_viewer/PluginViewerController.cpp" line="242"/>
        <source>genome_browser2_plugin_files</source>
        <translation>Soubory s přídavným modulem</translation>
    </message>
    <message>
        <location filename="../src/plugin_viewer/PluginViewerController.cpp" line="387"/>
        <source>item_type_plugin_label</source>
        <translation>Přídavný modul</translation>
    </message>
    <message>
        <location filename="../src/plugin_viewer/PluginViewerController.cpp" line="393"/>
        <location filename="../src/plugin_viewer/PluginViewerController.cpp" line="412"/>
        <source>item_state_on</source>
        <translation>Zapnuto</translation>
    </message>
    <message>
        <location filename="../src/plugin_viewer/PluginViewerController.cpp" line="409"/>
        <source>item_type_service_label</source>
        <translation>Služba</translation>
    </message>
    <message>
        <location filename="../src/plugin_viewer/PluginViewerController.cpp" line="413"/>
        <source>item_state_off</source>
        <translation>Vypnuto</translation>
    </message>
    <message>
        <location filename="../src/plugin_viewer/PluginViewerController.cpp" line="86"/>
        <source>enable_plugin_action</source>
        <translation>Povolit přídavný modul</translation>
    </message>
    <message>
        <location filename="../src/plugin_viewer/PluginViewerController.cpp" line="89"/>
        <source>disable_plugin_action</source>
        <translation>Odstranit přídavný modul</translation>
    </message>
    <message>
        <location filename="../src/plugin_viewer/PluginViewerController.cpp" line="260"/>
        <source>add_plugin_error_caption</source>
        <translation>Chyba!</translation>
    </message>
    <message>
        <location filename="../src/plugin_viewer/PluginViewerController.cpp" line="392"/>
        <source>removed_after_restart</source>
        <translation>k odstranění po opětovném spuštění</translation>
    </message>
</context>
<context>
    <name>U2::PluginViewerImpl</name>
    <message>
        <location filename="../src/plugin_viewer/PluginViewerImpl.h" line="18"/>
        <source>plugin_viewer_sname</source>
        <translation>Prohlížeč přídavných modulů</translation>
    </message>
    <message>
        <location filename="../src/plugin_viewer/PluginViewerImpl.h" line="18"/>
        <source>plugin_viewer_sdesc</source>
        <translation>Nástroj pro zviditelnění a zacházení se základními přídavnými moduly a službami</translation>
    </message>
</context>
<context>
    <name>U2::ProjectDialogController</name>
    <message>
        <location filename="../src/project_support/ProjectLoaderImpl.cpp" line="400"/>
        <source>Choose directory</source>
        <translation>Vybrat adresář</translation>
    </message>
</context>
<context>
    <name>U2::ProjectImpl</name>
    <message>
        <source>add_document_url_%1</source>
        <translation type="obsolete">Přidání dokumentu do projektu: %1</translation>
    </message>
    <message>
        <source>remove_documenturl_%1</source>
        <translation type="obsolete">Odstranění dokumentu z projektu: %1</translation>
    </message>
    <message>
        <location filename="../src/project_support/ProjectImpl.cpp" line="72"/>
        <source>Project URL is set to %1
</source>
        <translation>Adresa projektu (URL) je nastavena na %1
</translation>
    </message>
    <message>
        <location filename="../src/project_support/ProjectImpl.cpp" line="90"/>
        <source>Adding document to the project: %1</source>
        <translation>Dokument se přidává do projektu: %1</translation>
    </message>
    <message>
        <location filename="../src/project_support/ProjectImpl.cpp" line="117"/>
        <source>Not enough resources for load document, resource name: &apos;%1&apos; available: %2%3 requested: %4%3</source>
        <translation>Pro nahrání dokumentu není dostatek zdrojů, název zdroje: &apos;%1&apos; dostupných: %2%3 požadováno: %4%3</translation>
    </message>
    <message>
        <location filename="../src/project_support/ProjectImpl.cpp" line="124"/>
        <source>Removing document from the project: %1</source>
        <translation>Dokument se odstraňuje z projektu: %1</translation>
    </message>
</context>
<context>
    <name>U2::ProjectLoaderImpl</name>
    <message>
        <location filename="../src/project_support/ProjectLoaderImpl.cpp" line="37"/>
        <source>&amp;New project...</source>
        <translation>&amp;Nový projekt...</translation>
    </message>
    <message>
        <location filename="../src/project_support/ProjectLoaderImpl.cpp" line="141"/>
        <source>UGENE project file</source>
        <translation>Soubor s projektem UGENE</translation>
    </message>
    <message>
        <location filename="../src/project_support/ProjectLoaderImpl.cpp" line="143"/>
        <source>Select files to open...</source>
        <translation>Vybrat soubory k otevření...</translation>
    </message>
    <message>
        <location filename="../src/project_support/ProjectLoaderImpl.cpp" line="363"/>
        <source>new_project_default_name</source>
        <translation>Nový projekt</translation>
    </message>
    <message>
        <location filename="../src/project_support/ProjectLoaderImpl.cpp" line="364"/>
        <source>new_project_default_file</source>
        <translation>projekt</translation>
    </message>
    <message>
        <source>gb_project_file</source>
        <translation type="obsolete">Soubory projektu</translation>
    </message>
    <message>
        <location filename="../src/project_support/ProjectLoaderImpl.cpp" line="43"/>
        <source>New document from text...</source>
        <translation>Nový dokument z textu...</translation>
    </message>
    <message>
        <location filename="../src/project_support/ProjectLoaderImpl.cpp" line="48"/>
        <source>Open</source>
        <translation>Otevřít</translation>
    </message>
    <message>
        <location filename="../src/project_support/ProjectLoaderImpl.cpp" line="54"/>
        <source>Access remote database...</source>
        <translation>Přistoupit ke vzdálené databázi...</translation>
    </message>
    <message>
        <source>open_dialog_caption</source>
        <translation type="obsolete">Otevřít projekt nebo soubor s daty</translation>
    </message>
    <message>
        <location filename="../src/project_support/ProjectLoaderImpl.cpp" line="350"/>
        <source>Save project as</source>
        <translation>Uložit projekt jako</translation>
    </message>
    <message>
        <location filename="../src/project_support/ProjectLoaderImpl.cpp" line="351"/>
        <source>Save</source>
        <translation>Uložit</translation>
    </message>
    <message>
        <location filename="../src/project_support/ProjectLoaderImpl.cpp" line="69"/>
        <source>Recent Projects</source>
        <translation>Poslední projekty</translation>
    </message>
    <message>
        <location filename="../src/project_support/ProjectLoaderImpl.cpp" line="73"/>
        <source>Recent Files</source>
        <translation>Poslední soubory</translation>
    </message>
</context>
<context>
    <name>U2::ProjectServiceDisableTask</name>
    <message>
        <location filename="../src/project_support/ProjectServiceImpl.cpp" line="159"/>
        <source>project_disable_task</source>
        <translation>Zakázat projekt</translation>
    </message>
</context>
<context>
    <name>U2::ProjectServiceEnableTask</name>
    <message>
        <location filename="../src/project_support/ProjectServiceImpl.cpp" line="111"/>
        <source>project_enable_task</source>
        <translation>Povolit projekt</translation>
    </message>
    <message>
        <location filename="../src/project_support/ProjectServiceImpl.cpp" line="120"/>
        <source>&amp;Save all</source>
        <translation>&amp;Uložit vše</translation>
    </message>
    <message>
        <location filename="../src/project_support/ProjectServiceImpl.cpp" line="129"/>
        <source>&amp;Close project</source>
        <translation>&amp;Zavřít projekt</translation>
    </message>
    <message>
        <location filename="../src/project_support/ProjectServiceImpl.cpp" line="135"/>
        <source>Export project...</source>
        <translation>Vyvést projekt...</translation>
    </message>
    <message>
        <location filename="../src/project_support/ProjectServiceImpl.cpp" line="126"/>
        <source>Save project &amp;as...</source>
        <translation>Uložit projekt &amp;jako...</translation>
    </message>
</context>
<context>
    <name>U2::ProjectServiceImpl</name>
    <message>
        <location filename="../src/project_support/ProjectServiceImpl.cpp" line="26"/>
        <source>project_sname</source>
        <translation>Projekt</translation>
    </message>
    <message>
        <location filename="../src/project_support/ProjectServiceImpl.cpp" line="26"/>
        <source>project_sdesc</source>
        <translation>Projektová služba je dostupná, když je otevřen projekt. Další služby, které zavisejí na projektové službě budou automaticky spuštěny, jakmile je tato služba povolena.</translation>
    </message>
</context>
<context>
    <name>U2::ProjectViewImpl</name>
    <message>
        <location filename="../src/project_view/ProjectViewImpl.cpp" line="75"/>
        <source>projectview_sname</source>
        <translation>Prohlížení projektu</translation>
    </message>
    <message>
        <location filename="../src/project_view/ProjectViewImpl.cpp" line="75"/>
        <source>projectview_sdesc</source>
        <translation>Služba prohlížení projektu poskytuje základní funkce pro zviditelnění projektu a zacházení s ním</translation>
    </message>
    <message>
        <location filename="../src/project_view/ProjectViewImpl.cpp" line="127"/>
        <source>save_selected_modified_docs_action</source>
        <translation>Uložit vybrané dokumenty</translation>
    </message>
    <message>
        <source>creating_new_document_lm %1</source>
        <translation type="obsolete">Vytváří se nový dokument %1</translation>
    </message>
    <message>
        <source>adding_existing_document %1</source>
        <translation type="obsolete">Přidává se stávající dokument: %1</translation>
    </message>
    <message>
        <location filename="../src/project_view/ProjectViewImpl.cpp" line="426"/>
        <source>active_views_menu</source>
        <translation>Činné pohledy</translation>
    </message>
    <message>
        <location filename="../src/project_view/ProjectViewImpl.cpp" line="479"/>
        <source>activate_view_action_%1</source>
        <translation>Zapnout pohled: %1</translation>
    </message>
    <message>
        <location filename="../src/project_view/ProjectViewImpl.cpp" line="489"/>
        <source>open_view_action_%1</source>
        <translation>Otevřít nový pohled: %1</translation>
    </message>
    <message>
        <location filename="../src/project_view/ProjectViewImpl.cpp" line="498"/>
        <source>open_state_%1_%2</source>
        <translation>Otevřít uložený pohled &apos;%1&apos; se stavem &apos;%2&apos;</translation>
    </message>
    <message>
        <location filename="../src/project_view/ProjectViewImpl.cpp" line="519"/>
        <source>open_view_submenu_%1</source>
        <translation> &apos;%1&apos; stavy pohledu</translation>
    </message>
    <message>
        <location filename="../src/project_view/ProjectViewImpl.cpp" line="546"/>
        <source>add_to_view_action_%1</source>
        <translation>Přidat do pohledu: %1</translation>
    </message>
    <message>
        <location filename="../src/project_view/ProjectViewImpl.cpp" line="589"/>
        <source>open_view_menu</source>
        <translation>Otevřít pohled</translation>
    </message>
    <message>
        <location filename="../src/project_view/ProjectViewImpl.cpp" line="590"/>
        <source>add_to_view_menu</source>
        <translation>Přidat do pohledu</translation>
    </message>
    <message>
        <location filename="../src/project_view/ProjectViewImpl.cpp" line="654"/>
        <source>error_adding_object_to_view_title</source>
        <translation>Chyba!</translation>
    </message>
    <message>
        <location filename="../src/project_view/ProjectViewImpl.cpp" line="325"/>
        <source>unnamed_project_name</source>
        <translation>-</translation>
    </message>
    <message>
        <location filename="../src/project_view/ProjectViewImpl.cpp" line="119"/>
        <source>Open as...</source>
        <translation>Otevřít jako...</translation>
    </message>
    <message>
        <location filename="../src/project_view/ProjectViewImpl.cpp" line="130"/>
        <source>Relocate..</source>
        <translation>Přemístit...</translation>
    </message>
    <message>
        <location filename="../src/project_view/ProjectViewImpl.cpp" line="134"/>
        <source>Save a copy..</source>
        <translation>Uložit kopii...</translation>
    </message>
    <message>
        <location filename="../src/project_view/ProjectViewImpl.cpp" line="298"/>
        <source>Creating new document %1</source>
        <translation>Vytváří se nový dokument %1</translation>
    </message>
    <message>
        <location filename="../src/project_view/ProjectViewImpl.cpp" line="360"/>
        <source>Adding existing document %1</source>
        <translation>Přidává se stávající dokument %1</translation>
    </message>
    <message>
        <location filename="../src/project_view/ProjectViewImpl.cpp" line="381"/>
        <source>Add and load document</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/project_view/ProjectViewImpl.cpp" line="733"/>
        <source>Select new file location</source>
        <translation>Vybrat nové umístění souboru</translation>
    </message>
    <message>
        <source>Save a copy</source>
        <translation type="obsolete">Uložit kopii</translation>
    </message>
    <message>
        <location filename="../src/project_view/ProjectViewImpl.cpp" line="758"/>
        <source>Error</source>
        <translation>Chyba</translation>
    </message>
    <message>
        <location filename="../src/project_view/ProjectViewImpl.cpp" line="758"/>
        <source>Document with the same URL is added to the project. 
 Remove it from the project first.</source>
        <translation>Do projektu je přidán dokument se stejnou adresou (URL).
Nejprve jej z projektu odstraňte.</translation>
    </message>
    <message>
        <source>Question</source>
        <translation type="obsolete">Otázka</translation>
    </message>
    <message>
        <source>Add new document to the project?</source>
        <translation type="obsolete">Přidat nový dokument do projektu?</translation>
    </message>
</context>
<context>
    <name>U2::ProjectViewWidget</name>
    <message>
        <location filename="../src/project_view/ProjectViewImpl.cpp" line="57"/>
        <source>Project</source>
        <translation>Projekt</translation>
    </message>
    <message>
        <location filename="../src/project_view/ProjectViewImpl.cpp" line="50"/>
        <source>Group mode</source>
        <translation>Skupinový režim</translation>
    </message>
</context>
<context>
    <name>U2::RegisterProjectServiceTask</name>
    <message>
        <location filename="../src/project_support/ProjectTasksGui.cpp" line="396"/>
        <source>Register project</source>
        <translation>Zapsat projekt</translation>
    </message>
</context>
<context>
    <name>U2::ResourceSettingsGUIPageController</name>
    <message>
        <location filename="../src/app_settings/resource_settings/ResourceSettingsGUIController.cpp" line="12"/>
        <source>Resources</source>
        <translation>Zdroje</translation>
    </message>
</context>
<context>
    <name>U2::SaveOnlyProjectTask</name>
    <message>
        <location filename="../src/project_support/ProjectTasksGui.cpp" line="298"/>
        <source>Save project</source>
        <translation>Uložit projekt</translation>
    </message>
    <message>
        <location filename="../src/project_support/ProjectTasksGui.cpp" line="344"/>
        <source>Saving project %1</source>
        <translation>Ukládá se projekt %1</translation>
    </message>
</context>
<context>
    <name>U2::SaveProjectTask</name>
    <message>
        <location filename="../src/project_support/ProjectTasksGui.cpp" line="232"/>
        <source>save_project_task_name</source>
        <translation>Uložit projekt</translation>
    </message>
    <message>
        <location filename="../src/project_support/ProjectTasksGui.cpp" line="251"/>
        <source>UGENE</source>
        <translation>UGENE</translation>
    </message>
    <message>
        <location filename="../src/project_support/ProjectTasksGui.cpp" line="251"/>
        <source>Save current project?</source>
        <translation>Uložit nynější projekt?</translation>
    </message>
    <message>
        <location filename="../src/project_support/ProjectTasksGui.cpp" line="284"/>
        <source>Save documents, remove phantom docs, save  project</source>
        <translation>Uložit dokumenty, odstranit zdánlivé dokumenty, uložit projekt</translation>
    </message>
    <message>
        <source>question</source>
        <translation type="obsolete">Potvrzení</translation>
    </message>
    <message>
        <source>save_project_file_question</source>
        <translation type="obsolete">Uložit soubor s projektem?</translation>
    </message>
    <message>
        <location filename="../src/project_support/ProjectTasksGui.cpp" line="255"/>
        <source>My project</source>
        <translation>Můj projekt</translation>
    </message>
    <message>
        <source>Saving project %1</source>
        <translation type="obsolete">Ukládá se projekt %1</translation>
    </message>
</context>
<context>
    <name>U2::ScriptManagerDialog</name>
    <message>
        <source>script_registry_title</source>
        <translation type="obsolete">Soupis skriptů</translation>
    </message>
</context>
<context>
    <name>U2::ScriptManagerView</name>
    <message>
        <source>script_manager</source>
        <translation type="obsolete">Soupis skriptů</translation>
    </message>
</context>
<context>
    <name>U2::ScriptManagerWidgetImpl</name>
    <message>
        <source>Qt scripts</source>
        <translation type="obsolete">Skripty Qt/UGENE</translation>
    </message>
    <message>
        <source>All files</source>
        <translation type="obsolete">Všechny soubory</translation>
    </message>
    <message>
        <source>add_scripts_caption</source>
        <translation type="obsolete">Přidat skript</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation type="obsolete">Upozornění</translation>
    </message>
    <message>
        <source>script_%1_already_registered</source>
        <translation type="obsolete">Skript %1 je již zapsán</translation>
    </message>
    <message>
        <source>delete_question</source>
        <translation type="obsolete">Otázka</translation>
    </message>
    <message>
        <source>really_want_delete?</source>
        <translation type="obsolete">Opravdu chcete tento skript odstranit?</translation>
    </message>
</context>
<context>
    <name>U2::Shtirlitz</name>
    <message>
        <location filename="../src/shtirlitz/Shtirlitz.cpp" line="84"/>
        <source>Statistical reports</source>
        <translation>Statistické zprávy</translation>
    </message>
    <message>
        <location filename="../src/shtirlitz/Shtirlitz.cpp" line="90"/>
        <source>Shtirlitz is sending the first-time report</source>
        <translation>Shtirlitz posílá ihned zprávu</translation>
    </message>
    <message>
        <location filename="../src/shtirlitz/Shtirlitz.cpp" line="107"/>
        <source>%1 days passed passed since previous Shtirlitz&apos;s report. Shtirlitz is sending the new one.</source>
        <translation>Od předchozí Shtirlitzovy zprávy uplynulo %1 dnů. Shtirlitz posílá novou.</translation>
    </message>
</context>
<context>
    <name>U2::ShtirlitzTask</name>
    <message>
        <location filename="../src/shtirlitz/Shtirlitz.cpp" line="243"/>
        <source>Connecting to remote server</source>
        <translation>Připojuje se ke vzdálenému serveru</translation>
    </message>
    <message>
        <location filename="../src/shtirlitz/Shtirlitz.cpp" line="263"/>
        <source>Cannot resolve destination path for statistical reports</source>
        <translation>Nelze rozložit cílovou cestu pro statistické zprávy</translation>
    </message>
    <message>
        <location filename="../src/shtirlitz/Shtirlitz.cpp" line="267"/>
        <source>Network error while resolving destination URL: </source>
        <translation>Chyba v síti při rozložení cílové adresy (URL): </translation>
    </message>
    <message>
        <location filename="../src/shtirlitz/Shtirlitz.cpp" line="280"/>
        <source>Network error while sending report: </source>
        <translation>Chyba v síti při posílání zprávy: </translation>
    </message>
</context>
<context>
    <name>U2::ShutdownTask</name>
    <message>
        <location filename="../src/main_window/ShutdownTask.cpp" line="16"/>
        <source>shutdown_task_name</source>
        <translation>Zastavení provozu</translation>
    </message>
    <message>
        <location filename="../src/main_window/ShutdownTask.cpp" line="137"/>
        <source>Starting shutdown process...</source>
        <translation>Spouští se postup zastavení provozu...</translation>
    </message>
    <message>
        <source>Shutdown was canceled</source>
        <translation type="obsolete">Zastavení provozu bylo zrušeno</translation>
    </message>
    <message>
        <source>Shutdown failed, error: %1</source>
        <translation type="obsolete">Zastavení provozu se nepodařilo. Chyba: %1</translation>
    </message>
    <message>
        <location filename="../src/main_window/ShutdownTask.cpp" line="68"/>
        <source>Close windows</source>
        <translation>Zavřít okna</translation>
    </message>
    <message>
        <location filename="../src/main_window/ShutdownTask.cpp" line="105"/>
        <source>Cancel active tasks</source>
        <translation>Zrušit činné úkoly</translation>
    </message>
    <message>
        <location filename="../src/main_window/ShutdownTask.cpp" line="156"/>
        <source>Shutdown confirmation</source>
        <translation>Potvrzení zastavení provozu</translation>
    </message>
    <message>
        <location filename="../src/main_window/ShutdownTask.cpp" line="157"/>
        <source>There are active tasks. Stop them now?</source>
        <translation>Jsou zde činné úkoly. Zastavit je nyní?</translation>
    </message>
</context>
<context>
    <name>U2::TBoard</name>
    <message>
        <location filename="../src/main_window/AboutDialogController.cpp" line="367"/>
        <source>Pause</source>
        <translation>Přestávka</translation>
    </message>
</context>
<context>
    <name>U2::TVReportWindow</name>
    <message>
        <location filename="../src/task_view/TaskViewController.cpp" line="412"/>
        <source>report_for_%1</source>
        <translation>Zpráva o úkole [%1]</translation>
    </message>
    <message>
        <location filename="../src/task_view/TaskViewController.cpp" line="423"/>
        <source>Failed</source>
        <translation>Nepodařilo se</translation>
    </message>
    <message>
        <location filename="../src/task_view/TaskViewController.cpp" line="423"/>
        <source>Canceled</source>
        <translation>Zrušeno</translation>
    </message>
    <message>
        <location filename="../src/task_view/TaskViewController.cpp" line="423"/>
        <source>Finished</source>
        <translation>Dokončeno</translation>
    </message>
    <message>
        <location filename="../src/task_view/TaskViewController.cpp" line="424"/>
        <source>status</source>
        <translation>Stav</translation>
    </message>
    <message>
        <location filename="../src/task_view/TaskViewController.cpp" line="426"/>
        <source>error:</source>
        <translation>Chyba: </translation>
    </message>
    <message>
        <location filename="../src/task_view/TaskViewController.cpp" line="432"/>
        <source>time</source>
        <translation>Čas</translation>
    </message>
</context>
<context>
    <name>U2::TaskStatusBar</name>
    <message>
        <location filename="../src/task_view/TaskStatusBar.cpp" line="88"/>
        <source>%1Report for task: &apos;%2&apos;</source>
        <translation>%1Zpráva o úkole: %2</translation>
    </message>
    <message>
        <location filename="../src/task_view/TaskStatusBar.cpp" line="91"/>
        <source>%1&apos;%2&apos; task failed: %3</source>
        <translation>%1%2 se nepodařilo: %3</translation>
    </message>
    <message>
        <location filename="../src/task_view/TaskStatusBar.cpp" line="121"/>
        <source>num_reports_%1</source>
        <translation>Zprávy: %1</translation>
    </message>
    <message>
        <location filename="../src/task_view/TaskStatusBar.cpp" line="126"/>
        <source>no_active_tasks</source>
        <translation>Žádné činné úkoly</translation>
    </message>
    <message>
        <location filename="../src/task_view/TaskStatusBar.cpp" line="135"/>
        <source>running_task_%1</source>
        <translation>Běžící úkol: %1</translation>
    </message>
    <message>
        <location filename="../src/task_view/TaskStatusBar.cpp" line="144"/>
        <source>_info_%1</source>
        <translation>: %1</translation>
    </message>
    <message>
        <location filename="../src/task_view/TaskStatusBar.cpp" line="149"/>
        <source>num_tasks_%1_num_reports_%2</source>
        <translation>Úkoly: %1, Zprávy %2</translation>
    </message>
    <message>
        <location filename="../src/task_view/TaskStatusBar.cpp" line="151"/>
        <source>num_tasks_%1</source>
        <translation>Úkoly: %1</translation>
    </message>
    <message>
        <location filename="../src/task_view/TaskStatusBar.cpp" line="224"/>
        <source>%1 notification(s)</source>
        <translation>%1 oznámení</translation>
    </message>
    <message>
        <location filename="../src/task_view/TaskStatusBar.cpp" line="137"/>
        <source>canceling...</source>
        <translation>Ruší se...</translation>
    </message>
</context>
<context>
    <name>U2::TaskViewDockWidget</name>
    <message>
        <location filename="../src/task_view/TaskViewController.cpp" line="28"/>
        <source>Tasks</source>
        <translation>Úkoly</translation>
    </message>
    <message>
        <location filename="../src/task_view/TaskViewController.cpp" line="61"/>
        <source>cancel_task_action</source>
        <translation>Zrušit úkol</translation>
    </message>
    <message>
        <location filename="../src/task_view/TaskViewController.cpp" line="65"/>
        <source>view_task_report_action</source>
        <translation>Zobrazit zprávu</translation>
    </message>
    <message>
        <location filename="../src/task_view/TaskViewController.cpp" line="69"/>
        <source>remove_task_report_action</source>
        <translation>Odstranit zprávu</translation>
    </message>
    <message>
        <location filename="../src/task_view/TaskViewController.cpp" line="99"/>
        <source>task_name_column</source>
        <translation>Název úkolu</translation>
    </message>
    <message>
        <location filename="../src/task_view/TaskViewController.cpp" line="100"/>
        <source>task_current_desc_column</source>
        <translation>Popis stavu úkolu</translation>
    </message>
    <message>
        <location filename="../src/task_view/TaskViewController.cpp" line="101"/>
        <source>task_progress_column</source>
        <translation>Postup úkolu</translation>
    </message>
    <message>
        <location filename="../src/task_view/TaskViewController.cpp" line="102"/>
        <source>task_actions_column</source>
        <translation>Činnosti</translation>
    </message>
    <message>
        <source>New report available from task: %1</source>
        <translation type="obsolete">O úkolu je dostupná nová zpráva: %1</translation>
    </message>
    <message>
        <location filename="../src/task_view/TaskViewController.cpp" line="274"/>
        <source>Activating task report: %1</source>
        <translation>Zapíná se zpráva o úkolu: %1</translation>
    </message>
    <message>
        <location filename="../src/task_view/TaskViewController.cpp" line="494"/>
        <source>finished</source>
        <translation>Dokončeno</translation>
    </message>
    <message>
        <location filename="../src/task_view/TaskViewController.cpp" line="476"/>
        <source>Canceling...</source>
        <translation>Ruší se...</translation>
    </message>
    <message>
        <location filename="../src/task_view/TaskViewController.cpp" line="474"/>
        <source>Canceled</source>
        <translation>Zrušeno</translation>
    </message>
</context>
<context>
    <name>U2::UserApplicationsSettingsPageController</name>
    <message>
        <source>user_apps</source>
        <translation type="obsolete">Různá nastavení</translation>
    </message>
    <message>
        <location filename="../src/app_settings/user_apps_settings/UserApplicationsSettingsGUIController.cpp" line="17"/>
        <source>General</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/app_settings/user_apps_settings/UserApplicationsSettingsGUIController.cpp" line="23"/>
        <source>File with translations is not found: %1</source>
        <translation>Soubor s překlady nebyl nalezen: %1</translation>
    </message>
    <message>
        <location filename="../src/app_settings/user_apps_settings/UserApplicationsSettingsGUIController.cpp" line="37"/>
        <source>Illegal entry in translations file: %1</source>
        <translation>Neplatný záznam v souboru s překladem: %1</translation>
    </message>
    <message>
        <source>transmap_file_not_found_%1</source>
        <translation type="obsolete">Seznam překladů nebyl nalezen: %1</translation>
    </message>
    <message>
        <source>illegal_entry_%1</source>
        <translation type="obsolete">Neplatný záznam v seznamu překladů: &apos;%1&apos;</translation>
    </message>
    <message>
        <location filename="../src/app_settings/user_apps_settings/UserApplicationsSettingsGUIController.cpp" line="19"/>
        <source>Autodetection</source>
        <translation>Automatické zjištění</translation>
    </message>
</context>
<context>
    <name>U2::UserApplicationsSettingsPageWidget</name>
    <message>
        <location filename="../src/app_settings/user_apps_settings/UserApplicationsSettingsGUIController.cpp" line="114"/>
        <location filename="../src/app_settings/user_apps_settings/UserApplicationsSettingsGUIController.cpp" line="172"/>
        <source>Custom translation [%1]</source>
        <translation>Vlastní překlad [%1]</translation>
    </message>
    <message>
        <location filename="../src/app_settings/user_apps_settings/UserApplicationsSettingsGUIController.cpp" line="136"/>
        <source>file_not_exists</source>
        <translation>Soubor neexistuje</translation>
    </message>
    <message>
        <location filename="../src/app_settings/user_apps_settings/UserApplicationsSettingsGUIController.cpp" line="153"/>
        <source>select_wb_file_title</source>
        <translation>Vybrat internetový prohlížeč</translation>
    </message>
    <message>
        <location filename="../src/app_settings/user_apps_settings/UserApplicationsSettingsGUIController.cpp" line="160"/>
        <source>select_trans_file_title</source>
        <translation>Vybrat soubor s překladem</translation>
    </message>
    <message>
        <location filename="../src/app_settings/user_apps_settings/UserApplicationsSettingsGUIController.cpp" line="181"/>
        <location filename="../src/app_settings/user_apps_settings/UserApplicationsSettingsGUIController.cpp" line="193"/>
        <source>Choose Directory</source>
        <translation>Vybrat adresář</translation>
    </message>
</context>
<context>
    <name>UserApplicationsSettingsWidget</name>
    <message>
        <location filename="../src/app_settings/user_apps_settings/ui/UserApplicationsSettingsWidget.ui" line="26"/>
        <source>LangBoxTitle</source>
        <translation>Jazyk uživatelského rozhraní (použitý po opětovném spuštění)</translation>
    </message>
    <message>
        <location filename="../src/app_settings/user_apps_settings/ui/UserApplicationsSettingsWidget.ui" line="35"/>
        <location filename="../src/app_settings/user_apps_settings/ui/UserApplicationsSettingsWidget.ui" line="113"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../src/app_settings/user_apps_settings/ui/UserApplicationsSettingsWidget.ui" line="69"/>
        <source>web_browser</source>
        <translation>Upřednostňovaný internetový prohlížeč</translation>
    </message>
    <message>
        <location filename="../src/app_settings/user_apps_settings/ui/UserApplicationsSettingsWidget.ui" line="86"/>
        <source>use_default_web_browser</source>
        <translation>Výchozí systémový prohlížeč</translation>
    </message>
    <message>
        <location filename="../src/app_settings/user_apps_settings/ui/UserApplicationsSettingsWidget.ui" line="96"/>
        <source>web_browser_path</source>
        <translation>Zadaný spustitelný soubor</translation>
    </message>
    <message>
        <location filename="../src/app_settings/user_apps_settings/ui/UserApplicationsSettingsWidget.ui" line="125"/>
        <source>Project</source>
        <translation>Projekt</translation>
    </message>
    <message>
        <location filename="../src/app_settings/user_apps_settings/ui/UserApplicationsSettingsWidget.ui" line="131"/>
        <source>auto_open_project_at_startup</source>
        <translation>Otevřít poslední projekt při spuštění</translation>
    </message>
    <message>
        <location filename="../src/app_settings/user_apps_settings/ui/UserApplicationsSettingsWidget.ui" line="141"/>
        <source>Path to downloaded data:</source>
        <translation>Cesta ke staženým datům:</translation>
    </message>
    <message>
        <location filename="../src/app_settings/user_apps_settings/ui/UserApplicationsSettingsWidget.ui" line="152"/>
        <location filename="../src/app_settings/user_apps_settings/ui/UserApplicationsSettingsWidget.ui" line="191"/>
        <source>Browse...</source>
        <translation>Procházet...</translation>
    </message>
    <message>
        <location filename="../src/app_settings/user_apps_settings/ui/UserApplicationsSettingsWidget.ui" line="164"/>
        <source>Statistical reports</source>
        <translation>Statistické zprávy</translation>
    </message>
    <message>
        <location filename="../src/app_settings/user_apps_settings/ui/UserApplicationsSettingsWidget.ui" line="170"/>
        <source>Enable statistical reports collecting</source>
        <translation>Povolit sběr statistických zpráv</translation>
    </message>
    <message>
        <location filename="../src/app_settings/user_apps_settings/ui/UserApplicationsSettingsWidget.ui" line="180"/>
        <source>Path for temporary files</source>
        <translation>Cesta pro dočasné soubory</translation>
    </message>
    <message>
        <location filename="../src/app_settings/user_apps_settings/ui/UserApplicationsSettingsWidget.ui" line="45"/>
        <source>Appearance</source>
        <translation>Vzhled</translation>
    </message>
</context>
</TS>
